! ###########################################################################
!     RESUME : J13 = Jones et al. (2013) + Koehler et al. (2014), hereafter !
!                    J13 redenning law. Returns:                            !
!                                                                           !
!              q(λ) = A(λ)/A(V) for given λ in Å. Strictly valid from       !
!              400 to 1.000000E+09 Å, but values are extrapolated.          !
!                                                                           !
!     INPUT  : 01) l           -> λ                                         !
!              02) k           -> Variable set to 0 if run aborted          !
!                                                                           !
!     OUTPUT : 01) J13__LawOPT -> Value of q(λ)                             !
!                                                                           !
!     LOGS   : Needs to read the paper! How to implement R_V, if possible   !
!                                                                           !
!     PYTHON : Python compatibility using f2py revised. Better usage        !
!              with numpy.                                                  !
!                                                                           !
!     Written: Jean Michel Gomes © Copyright ®                              !
!        Date: Sun Oct 15 10:00:52 WEST 2006                                !
!     Checked: seg nov 23 16:04:53  WET 2020                                !
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
SUBROUTINE J13__LawOPT( n,l,q,R_V )

    use ModDataType

    implicit none
    integer  (kind=IB), intent(in) :: n
    real     (kind=RP), intent(in), dimension(0:n-1) :: l
    real     (kind=RP), intent(in) :: R_V
    real     (kind=RP), dimension(0:799) :: ll,ff
    real     (kind=RP), intent(out), dimension(0:n-1) :: q
    real     (kind=RP), dimension(0:0) :: aux,x
    real     (kind=RP) :: e

    !f2py real     (kind=RP), intent(in)  :: l
    !f2py                     intent(hide), depend(l) :: n=shape(l,0)
    
    !f2py real     (kind=RP), intent(out) :: q
    !f2py                     intent(hide), depend(q) :: n=shape(q,0)

    !f2py real     (kind=RP), intent(in)  :: R_V

    interface
       subroutine SPLINE1DArr( x,o,m,t,y,n,e,k )
         use ModDataType
         integer  (kind=IB), intent(in) :: n,m
         integer  (kind=IB), optional :: k
         integer  (kind=IB) :: i,j,IsShowOn
         real     (kind=RP), intent(in), dimension(0:n-1)  :: t,y
         real     (kind=RP), intent(in), dimension(0:m-1)  :: x
         
         real     (kind=RP), intent(out), dimension(0:m-1) :: o
         
         real     (kind=RP), optional :: e
       end subroutine SPLINE1DArr
    end interface
    
    q(0:n-1) = 0.0_RP
    e        = 1.0e-8_RP

! Table !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
    ll(000) = 4.000000E-002_RP ; ff(000) = 1.364886E+000_RP
    ll(001) = 4.065700E-002_RP ; ff(001) = 1.388609E+000_RP
    ll(002) = 4.132500E-002_RP ; ff(002) = 1.413096E+000_RP
    ll(003) = 4.200400E-002_RP ; ff(003) = 1.436884E+000_RP
    ll(004) = 4.269400E-002_RP ; ff(004) = 1.459027E+000_RP
    ll(005) = 4.339500E-002_RP ; ff(005) = 1.484617E+000_RP
    ll(006) = 4.410800E-002_RP ; ff(006) = 1.511472E+000_RP
    ll(007) = 4.483200E-002_RP ; ff(007) = 1.537607E+000_RP
    ll(008) = 4.556900E-002_RP ; ff(008) = 1.565611E+000_RP
    ll(009) = 4.631700E-002_RP ; ff(009) = 1.594568E+000_RP
    ll(010) = 4.707800E-002_RP ; ff(010) = 1.621958E+000_RP
    ll(011) = 4.785100E-002_RP ; ff(011) = 1.651952E+000_RP
    ll(012) = 4.863700E-002_RP ; ff(012) = 1.684250E+000_RP
    ll(013) = 4.943600E-002_RP ; ff(013) = 1.714404E+000_RP
    ll(014) = 5.024800E-002_RP ; ff(014) = 1.746935E+000_RP
    ll(015) = 5.107300E-002_RP ; ff(015) = 1.781383E+000_RP
    ll(016) = 5.191200E-002_RP ; ff(016) = 1.814587E+000_RP
    ll(017) = 5.276500E-002_RP ; ff(017) = 1.852014E+000_RP
    ll(018) = 5.363200E-002_RP ; ff(018) = 1.888332E+000_RP
    ll(019) = 5.451300E-002_RP ; ff(019) = 1.926867E+000_RP
    ll(020) = 5.540800E-002_RP ; ff(020) = 1.966405E+000_RP
    ll(021) = 5.631800E-002_RP ; ff(021) = 2.008868E+000_RP
    ll(022) = 5.724300E-002_RP ; ff(022) = 2.059609E+000_RP
    ll(023) = 5.818400E-002_RP ; ff(023) = 2.096069E+000_RP
    ll(024) = 5.913900E-002_RP ; ff(024) = 2.142507E+000_RP
    ll(025) = 6.011100E-002_RP ; ff(025) = 2.190773E+000_RP
    ll(026) = 6.109800E-002_RP ; ff(026) = 2.240962E+000_RP
    ll(027) = 6.210200E-002_RP ; ff(027) = 2.293185E+000_RP
    ll(028) = 6.312200E-002_RP ; ff(028) = 2.345797E+000_RP
    ll(029) = 6.415900E-002_RP ; ff(029) = 2.400363E+000_RP
    ll(030) = 6.521300E-002_RP ; ff(030) = 2.458184E+000_RP
    ll(031) = 6.628400E-002_RP ; ff(031) = 2.518098E+000_RP
    ll(032) = 6.737200E-002_RP ; ff(032) = 2.580677E+000_RP
    ll(033) = 6.847900E-002_RP ; ff(033) = 2.645507E+000_RP
    ll(034) = 6.960400E-002_RP ; ff(034) = 2.711319E+000_RP
    ll(035) = 7.074700E-002_RP ; ff(035) = 2.778929E+000_RP
    ll(036) = 7.190900E-002_RP ; ff(036) = 2.849149E+000_RP
    ll(037) = 7.309100E-002_RP ; ff(037) = 2.917645E+000_RP
    ll(038) = 7.429100E-002_RP ; ff(038) = 2.987203E+000_RP
    ll(039) = 7.551100E-002_RP ; ff(039) = 3.051469E+000_RP
    ll(040) = 7.675200E-002_RP ; ff(040) = 3.106782E+000_RP
    ll(041) = 7.801200E-002_RP ; ff(041) = 3.119578E+000_RP
    ll(042) = 7.929400E-002_RP ; ff(042) = 3.108520E+000_RP
    ll(043) = 8.059600E-002_RP ; ff(043) = 3.084514E+000_RP
    ll(044) = 8.192000E-002_RP ; ff(044) = 3.056343E+000_RP
    ll(045) = 8.326600E-002_RP ; ff(045) = 3.010672E+000_RP
    ll(046) = 8.463400E-002_RP ; ff(046) = 2.960701E+000_RP
    ll(047) = 8.602400E-002_RP ; ff(047) = 2.898687E+000_RP
    ll(048) = 8.743700E-002_RP ; ff(048) = 2.835883E+000_RP
    ll(049) = 8.887300E-002_RP ; ff(049) = 2.765957E+000_RP
    ll(050) = 9.033300E-002_RP ; ff(050) = 2.694220E+000_RP
    ll(051) = 9.181700E-002_RP ; ff(051) = 2.618892E+000_RP
    ll(052) = 9.332500E-002_RP ; ff(052) = 2.543280E+000_RP
    ll(053) = 9.485800E-002_RP ; ff(053) = 2.468909E+000_RP
    ll(054) = 9.641600E-002_RP ; ff(054) = 2.393974E+000_RP
    ll(055) = 9.799900E-002_RP ; ff(055) = 2.320357E+000_RP
    ll(056) = 9.960900E-002_RP ; ff(056) = 2.248648E+000_RP
    ll(057) = 1.012500E-001_RP ; ff(057) = 2.178334E+000_RP
    ll(058) = 1.029100E-001_RP ; ff(058) = 2.110842E+000_RP
    ll(059) = 1.046000E-001_RP ; ff(059) = 2.046046E+000_RP
    ll(060) = 1.063200E-001_RP ; ff(060) = 1.983639E+000_RP
    ll(061) = 1.080600E-001_RP ; ff(061) = 1.924262E+000_RP
    ll(062) = 1.098400E-001_RP ; ff(062) = 1.867331E+000_RP
    ll(063) = 1.116400E-001_RP ; ff(063) = 1.813775E+000_RP
    ll(064) = 1.134800E-001_RP ; ff(064) = 1.761226E+000_RP
    ll(065) = 1.153400E-001_RP ; ff(065) = 1.711265E+000_RP
    ll(066) = 1.172300E-001_RP ; ff(066) = 1.663089E+000_RP
    ll(067) = 1.191600E-001_RP ; ff(067) = 1.618363E+000_RP
    ll(068) = 1.211200E-001_RP ; ff(068) = 1.574998E+000_RP
    ll(069) = 1.231100E-001_RP ; ff(069) = 1.535391E+000_RP
    ll(070) = 1.251300E-001_RP ; ff(070) = 1.498943E+000_RP
    ll(071) = 1.271800E-001_RP ; ff(071) = 1.468568E+000_RP
    ll(072) = 1.292700E-001_RP ; ff(072) = 1.438107E+000_RP
    ll(073) = 1.314000E-001_RP ; ff(073) = 1.409111E+000_RP
    ll(074) = 1.335600E-001_RP ; ff(074) = 1.382509E+000_RP
    ll(075) = 1.357500E-001_RP ; ff(075) = 1.358476E+000_RP
    ll(076) = 1.379800E-001_RP ; ff(076) = 1.336467E+000_RP
    ll(077) = 1.402500E-001_RP ; ff(077) = 1.316090E+000_RP
    ll(078) = 1.425500E-001_RP ; ff(078) = 1.298256E+000_RP
    ll(079) = 1.448900E-001_RP ; ff(079) = 1.280686E+000_RP
    ll(080) = 1.472700E-001_RP ; ff(080) = 1.266199E+000_RP
    ll(081) = 1.496900E-001_RP ; ff(081) = 1.252050E+000_RP
    ll(082) = 1.521500E-001_RP ; ff(082) = 1.240542E+000_RP
    ll(083) = 1.546500E-001_RP ; ff(083) = 1.229981E+000_RP
    ll(084) = 1.571900E-001_RP ; ff(084) = 1.220685E+000_RP
    ll(085) = 1.597700E-001_RP ; ff(085) = 1.212609E+000_RP
    ll(086) = 1.623900E-001_RP ; ff(086) = 1.205132E+000_RP
    ll(087) = 1.650600E-001_RP ; ff(087) = 1.199661E+000_RP
    ll(088) = 1.677700E-001_RP ; ff(088) = 1.195918E+000_RP
    ll(089) = 1.705300E-001_RP ; ff(089) = 1.194093E+000_RP
    ll(090) = 1.733300E-001_RP ; ff(090) = 1.191483E+000_RP
    ll(091) = 1.761800E-001_RP ; ff(091) = 1.196053E+000_RP
    ll(092) = 1.790700E-001_RP ; ff(092) = 1.202002E+000_RP
    ll(093) = 1.820100E-001_RP ; ff(093) = 1.219401E+000_RP
    ll(094) = 1.850000E-001_RP ; ff(094) = 1.240943E+000_RP
    ll(095) = 1.880400E-001_RP ; ff(095) = 1.271330E+000_RP
    ll(096) = 1.911300E-001_RP ; ff(096) = 1.306170E+000_RP
    ll(097) = 1.942700E-001_RP ; ff(097) = 1.345495E+000_RP
    ll(098) = 1.974600E-001_RP ; ff(098) = 1.386039E+000_RP
    ll(099) = 2.007000E-001_RP ; ff(099) = 1.426158E+000_RP
    ll(100) = 2.040000E-001_RP ; ff(100) = 1.459622E+000_RP
    ll(101) = 2.073500E-001_RP ; ff(101) = 1.487051E+000_RP
    ll(102) = 2.107600E-001_RP ; ff(102) = 1.501418E+000_RP
    ll(103) = 2.142200E-001_RP ; ff(103) = 1.510082E+000_RP
    ll(104) = 2.177400E-001_RP ; ff(104) = 1.504331E+000_RP
    ll(105) = 2.213100E-001_RP ; ff(105) = 1.493021E+000_RP
    ll(106) = 2.249500E-001_RP ; ff(106) = 1.470894E+000_RP
    ll(107) = 2.286400E-001_RP ; ff(107) = 1.445715E+000_RP
    ll(108) = 2.324000E-001_RP ; ff(108) = 1.415653E+000_RP
    ll(109) = 2.362200E-001_RP ; ff(109) = 1.383655E+000_RP
    ll(110) = 2.401000E-001_RP ; ff(110) = 1.350821E+000_RP
    ll(111) = 2.440400E-001_RP ; ff(111) = 1.318084E+000_RP
    ll(112) = 2.480500E-001_RP ; ff(112) = 1.286909E+000_RP
    ll(113) = 2.521200E-001_RP ; ff(113) = 1.256732E+000_RP
    ll(114) = 2.562700E-001_RP ; ff(114) = 1.228765E+000_RP
    ll(115) = 2.604700E-001_RP ; ff(115) = 1.201826E+000_RP
    ll(116) = 2.647500E-001_RP ; ff(116) = 1.176070E+000_RP
    ll(117) = 2.691000E-001_RP ; ff(117) = 1.151022E+000_RP
    ll(118) = 2.735200E-001_RP ; ff(118) = 1.127531E+000_RP
    ll(119) = 2.780200E-001_RP ; ff(119) = 1.104550E+000_RP
    ll(120) = 2.825800E-001_RP ; ff(120) = 1.082026E+000_RP
    ll(121) = 2.872200E-001_RP ; ff(121) = 1.060466E+000_RP
    ll(122) = 2.919400E-001_RP ; ff(122) = 1.038254E+000_RP
    ll(123) = 2.967400E-001_RP ; ff(123) = 1.015682E+000_RP
    ll(124) = 3.016100E-001_RP ; ff(124) = 9.935960E-001_RP
    ll(125) = 3.065700E-001_RP ; ff(125) = 9.702626E-001_RP
    ll(126) = 3.116000E-001_RP ; ff(126) = 9.472957E-001_RP
    ll(127) = 3.167200E-001_RP ; ff(127) = 9.248561E-001_RP
    ll(128) = 3.219200E-001_RP ; ff(128) = 9.031252E-001_RP
    ll(129) = 3.272100E-001_RP ; ff(129) = 8.820686E-001_RP
    ll(130) = 3.325800E-001_RP ; ff(130) = 8.619080E-001_RP
    ll(131) = 3.380500E-001_RP ; ff(131) = 8.425060E-001_RP
    ll(132) = 3.436000E-001_RP ; ff(132) = 8.242647E-001_RP
    ll(133) = 3.492400E-001_RP ; ff(133) = 8.062417E-001_RP
    ll(134) = 3.549800E-001_RP ; ff(134) = 7.892843E-001_RP
    ll(135) = 3.608100E-001_RP ; ff(135) = 7.733940E-001_RP
    ll(136) = 3.667400E-001_RP ; ff(136) = 7.581819E-001_RP
    ll(137) = 3.727600E-001_RP ; ff(137) = 7.442316E-001_RP
    ll(138) = 3.788800E-001_RP ; ff(138) = 7.309709E-001_RP
    ll(139) = 3.851100E-001_RP ; ff(139) = 7.190889E-001_RP
    ll(140) = 3.914300E-001_RP ; ff(140) = 7.078142E-001_RP
    ll(141) = 3.978600E-001_RP ; ff(141) = 6.971936E-001_RP
    ll(142) = 4.044000E-001_RP ; ff(142) = 6.866743E-001_RP
    ll(143) = 4.110400E-001_RP ; ff(143) = 6.762635E-001_RP
    ll(144) = 4.177900E-001_RP ; ff(144) = 6.658386E-001_RP
    ll(145) = 4.246600E-001_RP ; ff(145) = 6.551844E-001_RP
    ll(146) = 4.316300E-001_RP ; ff(146) = 6.444445E-001_RP
    ll(147) = 4.387200E-001_RP ; ff(147) = 6.332374E-001_RP
    ll(148) = 4.459300E-001_RP ; ff(148) = 6.216129E-001_RP
    ll(149) = 4.532500E-001_RP ; ff(149) = 6.093984E-001_RP
    ll(150) = 4.607000E-001_RP ; ff(150) = 5.967663E-001_RP
    ll(151) = 4.682600E-001_RP ; ff(151) = 5.838937E-001_RP
    ll(152) = 4.759600E-001_RP ; ff(152) = 5.710873E-001_RP
    ll(153) = 4.837700E-001_RP ; ff(153) = 5.585544E-001_RP
    ll(154) = 4.917200E-001_RP ; ff(154) = 5.465822E-001_RP
    ll(155) = 4.998000E-001_RP ; ff(155) = 5.353081E-001_RP
    ll(156) = 5.080100E-001_RP ; ff(156) = 5.248576E-001_RP
    ll(157) = 5.163500E-001_RP ; ff(157) = 5.153216E-001_RP
    ll(158) = 5.248300E-001_RP ; ff(158) = 5.068146E-001_RP
    ll(159) = 5.334500E-001_RP ; ff(159) = 4.990616E-001_RP
    ll(160) = 5.422200E-001_RP ; ff(160) = 4.917302E-001_RP
    ll(161) = 5.511200E-001_RP ; ff(161) = 4.848608E-001_RP
    ll(162) = 5.601800E-001_RP ; ff(162) = 4.783119E-001_RP
    ll(163) = 5.693800E-001_RP ; ff(163) = 4.720188E-001_RP
    ll(164) = 5.787300E-001_RP ; ff(164) = 4.656488E-001_RP
    ll(165) = 5.882400E-001_RP ; ff(165) = 4.588677E-001_RP
    ll(166) = 5.979000E-001_RP ; ff(166) = 4.515018E-001_RP
    ll(167) = 6.077200E-001_RP ; ff(167) = 4.435377E-001_RP
    ll(168) = 6.177000E-001_RP ; ff(168) = 4.349813E-001_RP
    ll(169) = 6.278500E-001_RP ; ff(169) = 4.258482E-001_RP
    ll(170) = 6.381600E-001_RP ; ff(170) = 4.163130E-001_RP
    ll(171) = 6.486400E-001_RP ; ff(171) = 4.065625E-001_RP
    ll(172) = 6.593000E-001_RP ; ff(172) = 3.968181E-001_RP
    ll(173) = 6.701300E-001_RP ; ff(173) = 3.871602E-001_RP
    ll(174) = 6.811300E-001_RP ; ff(174) = 3.777036E-001_RP
    ll(175) = 6.923200E-001_RP ; ff(175) = 3.685485E-001_RP
    ll(176) = 7.036900E-001_RP ; ff(176) = 3.598914E-001_RP
    ll(177) = 7.152500E-001_RP ; ff(177) = 3.517924E-001_RP
    ll(178) = 7.270000E-001_RP ; ff(178) = 3.442541E-001_RP
    ll(179) = 7.389400E-001_RP ; ff(179) = 3.372259E-001_RP
    ll(180) = 7.510800E-001_RP ; ff(180) = 3.306226E-001_RP
    ll(181) = 7.634200E-001_RP ; ff(181) = 3.246404E-001_RP
    ll(182) = 7.759600E-001_RP ; ff(182) = 3.191518E-001_RP
    ll(183) = 7.887000E-001_RP ; ff(183) = 3.140250E-001_RP
    ll(184) = 8.016600E-001_RP ; ff(184) = 3.090617E-001_RP
    ll(185) = 8.148300E-001_RP ; ff(185) = 3.041450E-001_RP
    ll(186) = 8.282100E-001_RP ; ff(186) = 2.991994E-001_RP
    ll(187) = 8.418100E-001_RP ; ff(187) = 2.941831E-001_RP
    ll(188) = 8.556400E-001_RP ; ff(188) = 2.889590E-001_RP
    ll(189) = 8.697000E-001_RP ; ff(189) = 2.833821E-001_RP
    ll(190) = 8.839800E-001_RP ; ff(190) = 2.773872E-001_RP
    ll(191) = 8.985000E-001_RP ; ff(191) = 2.710017E-001_RP
    ll(192) = 9.132600E-001_RP ; ff(192) = 2.642331E-001_RP
    ll(193) = 9.282600E-001_RP ; ff(193) = 2.571080E-001_RP
    ll(194) = 9.435100E-001_RP ; ff(194) = 2.497788E-001_RP
    ll(195) = 9.590100E-001_RP ; ff(195) = 2.424255E-001_RP
    ll(196) = 9.747600E-001_RP ; ff(196) = 2.352086E-001_RP
    ll(197) = 9.907700E-001_RP ; ff(197) = 2.281999E-001_RP
    ll(198) = 1.007000E+000_RP ; ff(198) = 2.215238E-001_RP
    ll(199) = 1.023600E+000_RP ; ff(199) = 2.152175E-001_RP
    ll(200) = 1.040400E+000_RP ; ff(200) = 2.094853E-001_RP
    ll(201) = 1.057500E+000_RP ; ff(201) = 2.043987E-001_RP
    ll(202) = 1.074900E+000_RP ; ff(202) = 1.998563E-001_RP
    ll(203) = 1.092500E+000_RP ; ff(203) = 1.957279E-001_RP
    ll(204) = 1.110500E+000_RP ; ff(204) = 1.918570E-001_RP
    ll(205) = 1.128700E+000_RP ; ff(205) = 1.882614E-001_RP
    ll(206) = 1.147200E+000_RP ; ff(206) = 1.848765E-001_RP
    ll(207) = 1.166100E+000_RP ; ff(207) = 1.815820E-001_RP
    ll(208) = 1.185200E+000_RP ; ff(208) = 1.782325E-001_RP
    ll(209) = 1.204700E+000_RP ; ff(209) = 1.746694E-001_RP
    ll(210) = 1.224500E+000_RP ; ff(210) = 1.708880E-001_RP
    ll(211) = 1.244600E+000_RP ; ff(211) = 1.668846E-001_RP
    ll(212) = 1.265100E+000_RP ; ff(212) = 1.626127E-001_RP
    ll(213) = 1.285800E+000_RP ; ff(213) = 1.581328E-001_RP
    ll(214) = 1.307000E+000_RP ; ff(214) = 1.534400E-001_RP
    ll(215) = 1.328400E+000_RP ; ff(215) = 1.487411E-001_RP
    ll(216) = 1.350200E+000_RP ; ff(216) = 1.440477E-001_RP
    ll(217) = 1.372400E+000_RP ; ff(217) = 1.394007E-001_RP
    ll(218) = 1.395000E+000_RP ; ff(218) = 1.348651E-001_RP
    ll(219) = 1.417900E+000_RP ; ff(219) = 1.305628E-001_RP
    ll(220) = 1.441200E+000_RP ; ff(220) = 1.265649E-001_RP
    ll(221) = 1.464800E+000_RP ; ff(221) = 1.228863E-001_RP
    ll(222) = 1.488900E+000_RP ; ff(222) = 1.193931E-001_RP
    ll(223) = 1.513400E+000_RP ; ff(223) = 1.161291E-001_RP
    ll(224) = 1.538200E+000_RP ; ff(224) = 1.131230E-001_RP
    ll(225) = 1.563500E+000_RP ; ff(225) = 1.103593E-001_RP
    ll(226) = 1.589200E+000_RP ; ff(226) = 1.078974E-001_RP
    ll(227) = 1.615300E+000_RP ; ff(227) = 1.056110E-001_RP
    ll(228) = 1.641800E+000_RP ; ff(228) = 1.033873E-001_RP
    ll(229) = 1.668800E+000_RP ; ff(229) = 1.011863E-001_RP
    ll(230) = 1.696200E+000_RP ; ff(230) = 9.898662E-002_RP
    ll(231) = 1.724000E+000_RP ; ff(231) = 9.674482E-002_RP
    ll(232) = 1.752400E+000_RP ; ff(232) = 9.437964E-002_RP
    ll(233) = 1.781100E+000_RP ; ff(233) = 9.189701E-002_RP
    ll(234) = 1.810400E+000_RP ; ff(234) = 8.932049E-002_RP
    ll(235) = 1.840100E+000_RP ; ff(235) = 8.666768E-002_RP
    ll(236) = 1.870400E+000_RP ; ff(236) = 8.388028E-002_RP
    ll(237) = 1.901100E+000_RP ; ff(237) = 8.101238E-002_RP
    ll(238) = 1.932300E+000_RP ; ff(238) = 7.814144E-002_RP
    ll(239) = 1.964100E+000_RP ; ff(239) = 7.531527E-002_RP
    ll(240) = 1.996300E+000_RP ; ff(240) = 7.263327E-002_RP
    ll(241) = 2.029100E+000_RP ; ff(241) = 7.008728E-002_RP
    ll(242) = 2.062400E+000_RP ; ff(242) = 6.771231E-002_RP
    ll(243) = 2.096300E+000_RP ; ff(243) = 6.556721E-002_RP
    ll(244) = 2.130700E+000_RP ; ff(244) = 6.362875E-002_RP
    ll(245) = 2.165700E+000_RP ; ff(245) = 6.185796E-002_RP
    ll(246) = 2.201300E+000_RP ; ff(246) = 6.020407E-002_RP
    ll(247) = 2.237500E+000_RP ; ff(247) = 5.864842E-002_RP
    ll(248) = 2.274200E+000_RP ; ff(248) = 5.718727E-002_RP
    ll(249) = 2.311600E+000_RP ; ff(249) = 5.580022E-002_RP
    ll(250) = 2.349600E+000_RP ; ff(250) = 5.447149E-002_RP
    ll(251) = 2.388100E+000_RP ; ff(251) = 5.315895E-002_RP
    ll(252) = 2.427400E+000_RP ; ff(252) = 5.180486E-002_RP
    ll(253) = 2.467200E+000_RP ; ff(253) = 5.043405E-002_RP
    ll(254) = 2.507800E+000_RP ; ff(254) = 4.903435E-002_RP
    ll(255) = 2.549000E+000_RP ; ff(255) = 4.760444E-002_RP
    ll(256) = 2.590800E+000_RP ; ff(256) = 4.614886E-002_RP
    ll(257) = 2.633400E+000_RP ; ff(257) = 4.467844E-002_RP
    ll(258) = 2.676600E+000_RP ; ff(258) = 4.322391E-002_RP
    ll(259) = 2.720600E+000_RP ; ff(259) = 4.180065E-002_RP
    ll(260) = 2.765300E+000_RP ; ff(260) = 4.042298E-002_RP
    ll(261) = 2.810700E+000_RP ; ff(261) = 3.910000E-002_RP
    ll(262) = 2.856900E+000_RP ; ff(262) = 3.785429E-002_RP
    ll(263) = 2.903800E+000_RP ; ff(263) = 3.667566E-002_RP
    ll(264) = 2.951500E+000_RP ; ff(264) = 3.555468E-002_RP
    ll(265) = 3.000000E+000_RP ; ff(265) = 3.128564E-002_RP
    ll(266) = 3.015900E+000_RP ; ff(266) = 3.093052E-002_RP
    ll(267) = 3.032000E+000_RP ; ff(267) = 3.058278E-002_RP
    ll(268) = 3.048100E+000_RP ; ff(268) = 3.024711E-002_RP
    ll(269) = 3.064300E+000_RP ; ff(269) = 2.992074E-002_RP
    ll(270) = 3.080600E+000_RP ; ff(270) = 2.960417E-002_RP
    ll(271) = 3.096900E+000_RP ; ff(271) = 2.929885E-002_RP
    ll(272) = 3.113400E+000_RP ; ff(272) = 2.898650E-002_RP
    ll(273) = 3.130000E+000_RP ; ff(273) = 2.868129E-002_RP
    ll(274) = 3.146600E+000_RP ; ff(274) = 2.838778E-002_RP
    ll(275) = 3.163300E+000_RP ; ff(275) = 2.810386E-002_RP
    ll(276) = 3.180100E+000_RP ; ff(276) = 2.783112E-002_RP
    ll(277) = 3.197000E+000_RP ; ff(277) = 2.758948E-002_RP
    ll(278) = 3.214000E+000_RP ; ff(278) = 2.736557E-002_RP
    ll(279) = 3.231100E+000_RP ; ff(279) = 2.717551E-002_RP
    ll(280) = 3.248300E+000_RP ; ff(280) = 2.706286E-002_RP
    ll(281) = 3.265500E+000_RP ; ff(281) = 2.699182E-002_RP
    ll(282) = 3.282900E+000_RP ; ff(282) = 2.682228E-002_RP
    ll(283) = 3.300300E+000_RP ; ff(283) = 2.642057E-002_RP
    ll(284) = 3.317900E+000_RP ; ff(284) = 2.606063E-002_RP
    ll(285) = 3.335500E+000_RP ; ff(285) = 2.577579E-002_RP
    ll(286) = 3.353200E+000_RP ; ff(286) = 2.557674E-002_RP
    ll(287) = 3.371100E+000_RP ; ff(287) = 2.549142E-002_RP
    ll(288) = 3.389000E+000_RP ; ff(288) = 2.527964E-002_RP
    ll(289) = 3.407000E+000_RP ; ff(289) = 2.511714E-002_RP
    ll(290) = 3.425100E+000_RP ; ff(290) = 2.498097E-002_RP
    ll(291) = 3.443300E+000_RP ; ff(291) = 2.457014E-002_RP
    ll(292) = 3.461600E+000_RP ; ff(292) = 2.429303E-002_RP
    ll(293) = 3.480000E+000_RP ; ff(293) = 2.406757E-002_RP
    ll(294) = 3.498500E+000_RP ; ff(294) = 2.378508E-002_RP
    ll(295) = 3.517100E+000_RP ; ff(295) = 2.347110E-002_RP
    ll(296) = 3.535800E+000_RP ; ff(296) = 2.309480E-002_RP
    ll(297) = 3.554600E+000_RP ; ff(297) = 2.277391E-002_RP
    ll(298) = 3.573500E+000_RP ; ff(298) = 2.248701E-002_RP
    ll(299) = 3.592500E+000_RP ; ff(299) = 2.221459E-002_RP
    ll(300) = 3.611500E+000_RP ; ff(300) = 2.194949E-002_RP
    ll(301) = 3.630700E+000_RP ; ff(301) = 2.168516E-002_RP
    ll(302) = 3.650000E+000_RP ; ff(302) = 2.141739E-002_RP
    ll(303) = 3.669400E+000_RP ; ff(303) = 2.113083E-002_RP
    ll(304) = 3.688900E+000_RP ; ff(304) = 2.084315E-002_RP
    ll(305) = 3.708500E+000_RP ; ff(305) = 2.055416E-002_RP
    ll(306) = 3.728300E+000_RP ; ff(306) = 2.026303E-002_RP
    ll(307) = 3.748100E+000_RP ; ff(307) = 1.997303E-002_RP
    ll(308) = 3.768000E+000_RP ; ff(308) = 1.969490E-002_RP
    ll(309) = 3.788000E+000_RP ; ff(309) = 1.942667E-002_RP
    ll(310) = 3.808100E+000_RP ; ff(310) = 1.915925E-002_RP
    ll(311) = 3.828400E+000_RP ; ff(311) = 1.889155E-002_RP
    ll(312) = 3.848700E+000_RP ; ff(312) = 1.862667E-002_RP
    ll(313) = 3.869200E+000_RP ; ff(313) = 1.836229E-002_RP
    ll(314) = 3.889700E+000_RP ; ff(314) = 1.810148E-002_RP
    ll(315) = 3.910400E+000_RP ; ff(315) = 1.784252E-002_RP
    ll(316) = 3.931200E+000_RP ; ff(316) = 1.758716E-002_RP
    ll(317) = 3.952100E+000_RP ; ff(317) = 1.733605E-002_RP
    ll(318) = 3.973100E+000_RP ; ff(318) = 1.708962E-002_RP
    ll(319) = 3.994200E+000_RP ; ff(319) = 1.684819E-002_RP
    ll(320) = 4.015400E+000_RP ; ff(320) = 1.661182E-002_RP
    ll(321) = 4.036800E+000_RP ; ff(321) = 1.637978E-002_RP
    ll(322) = 4.058200E+000_RP ; ff(322) = 1.615446E-002_RP
    ll(323) = 4.079800E+000_RP ; ff(323) = 1.593409E-002_RP
    ll(324) = 4.101500E+000_RP ; ff(324) = 1.571981E-002_RP
    ll(325) = 4.123300E+000_RP ; ff(325) = 1.551152E-002_RP
    ll(326) = 4.145200E+000_RP ; ff(326) = 1.530341E-002_RP
    ll(327) = 4.167200E+000_RP ; ff(327) = 1.509671E-002_RP
    ll(328) = 4.189400E+000_RP ; ff(328) = 1.489486E-002_RP
    ll(329) = 4.211700E+000_RP ; ff(329) = 1.469871E-002_RP
    ll(330) = 4.234000E+000_RP ; ff(330) = 1.450907E-002_RP
    ll(331) = 4.256500E+000_RP ; ff(331) = 1.432362E-002_RP
    ll(332) = 4.279200E+000_RP ; ff(332) = 1.414357E-002_RP
    ll(333) = 4.301900E+000_RP ; ff(333) = 1.397608E-002_RP
    ll(334) = 4.324800E+000_RP ; ff(334) = 1.381124E-002_RP
    ll(335) = 4.347700E+000_RP ; ff(335) = 1.365051E-002_RP
    ll(336) = 4.370900E+000_RP ; ff(336) = 1.349188E-002_RP
    ll(337) = 4.394100E+000_RP ; ff(337) = 1.333765E-002_RP
    ll(338) = 4.417400E+000_RP ; ff(338) = 1.318713E-002_RP
    ll(339) = 4.440900E+000_RP ; ff(339) = 1.303990E-002_RP
    ll(340) = 4.464500E+000_RP ; ff(340) = 1.289610E-002_RP
    ll(341) = 4.488200E+000_RP ; ff(341) = 1.275501E-002_RP
    ll(342) = 4.512100E+000_RP ; ff(342) = 1.261594E-002_RP
    ll(343) = 4.536100E+000_RP ; ff(343) = 1.247932E-002_RP
    ll(344) = 4.560200E+000_RP ; ff(344) = 1.234512E-002_RP
    ll(345) = 4.584400E+000_RP ; ff(345) = 1.221337E-002_RP
    ll(346) = 4.608800E+000_RP ; ff(346) = 1.207948E-002_RP
    ll(347) = 4.633300E+000_RP ; ff(347) = 1.194604E-002_RP
    ll(348) = 4.657900E+000_RP ; ff(348) = 1.181419E-002_RP
    ll(349) = 4.682700E+000_RP ; ff(349) = 1.168253E-002_RP
    ll(350) = 4.707600E+000_RP ; ff(350) = 1.155072E-002_RP
    ll(351) = 4.732600E+000_RP ; ff(351) = 1.141850E-002_RP
    ll(352) = 4.757700E+000_RP ; ff(352) = 1.128586E-002_RP
    ll(353) = 4.783000E+000_RP ; ff(353) = 1.115708E-002_RP
    ll(354) = 4.808400E+000_RP ; ff(354) = 1.103226E-002_RP
    ll(355) = 4.834000E+000_RP ; ff(355) = 1.090758E-002_RP
    ll(356) = 4.859700E+000_RP ; ff(356) = 1.078362E-002_RP
    ll(357) = 4.885500E+000_RP ; ff(357) = 1.065995E-002_RP
    ll(358) = 4.911500E+000_RP ; ff(358) = 1.053579E-002_RP
    ll(359) = 4.937600E+000_RP ; ff(359) = 1.041133E-002_RP
    ll(360) = 4.963800E+000_RP ; ff(360) = 1.028449E-002_RP
    ll(361) = 4.990200E+000_RP ; ff(361) = 1.014720E-002_RP
    ll(362) = 5.016700E+000_RP ; ff(362) = 1.000993E-002_RP
    ll(363) = 5.043400E+000_RP ; ff(363) = 9.872213E-003_RP
    ll(364) = 5.070200E+000_RP ; ff(364) = 9.734545E-003_RP
    ll(365) = 5.097100E+000_RP ; ff(365) = 9.596914E-003_RP
    ll(366) = 5.124200E+000_RP ; ff(366) = 9.459239E-003_RP
    ll(367) = 5.151500E+000_RP ; ff(367) = 9.321731E-003_RP
    ll(368) = 5.178800E+000_RP ; ff(368) = 9.186386E-003_RP
    ll(369) = 5.206400E+000_RP ; ff(369) = 9.053041E-003_RP
    ll(370) = 5.234000E+000_RP ; ff(370) = 8.921643E-003_RP
    ll(371) = 5.261800E+000_RP ; ff(371) = 8.791525E-003_RP
    ll(372) = 5.289800E+000_RP ; ff(372) = 8.662863E-003_RP
    ll(373) = 5.317900E+000_RP ; ff(373) = 8.535846E-003_RP
    ll(374) = 5.346200E+000_RP ; ff(374) = 8.409628E-003_RP
    ll(375) = 5.374600E+000_RP ; ff(375) = 8.284607E-003_RP
    ll(376) = 5.403200E+000_RP ; ff(376) = 8.162427E-003_RP
    ll(377) = 5.431900E+000_RP ; ff(377) = 8.044119E-003_RP
    ll(378) = 5.460800E+000_RP ; ff(378) = 7.928004E-003_RP
    ll(379) = 5.489800E+000_RP ; ff(379) = 7.814535E-003_RP
    ll(380) = 5.519000E+000_RP ; ff(380) = 7.703421E-003_RP
    ll(381) = 5.548300E+000_RP ; ff(381) = 7.595295E-003_RP
    ll(382) = 5.577800E+000_RP ; ff(382) = 7.489861E-003_RP
    ll(383) = 5.607400E+000_RP ; ff(383) = 7.387368E-003_RP
    ll(384) = 5.637200E+000_RP ; ff(384) = 7.287383E-003_RP
    ll(385) = 5.667200E+000_RP ; ff(385) = 7.190329E-003_RP
    ll(386) = 5.697300E+000_RP ; ff(386) = 7.095666E-003_RP
    ll(387) = 5.727600E+000_RP ; ff(387) = 7.003191E-003_RP
    ll(388) = 5.758000E+000_RP ; ff(388) = 6.913480E-003_RP
    ll(389) = 5.788600E+000_RP ; ff(389) = 6.826446E-003_RP
    ll(390) = 5.819400E+000_RP ; ff(390) = 6.742468E-003_RP
    ll(391) = 5.850300E+000_RP ; ff(391) = 6.662072E-003_RP
    ll(392) = 5.881400E+000_RP ; ff(392) = 6.585714E-003_RP
    ll(393) = 5.912700E+000_RP ; ff(393) = 6.514131E-003_RP
    ll(394) = 5.944100E+000_RP ; ff(394) = 6.447941E-003_RP
    ll(395) = 5.975700E+000_RP ; ff(395) = 6.388922E-003_RP
    ll(396) = 6.007400E+000_RP ; ff(396) = 6.338493E-003_RP
    ll(397) = 6.039400E+000_RP ; ff(397) = 6.299458E-003_RP
    ll(398) = 6.071500E+000_RP ; ff(398) = 6.275677E-003_RP
    ll(399) = 6.103700E+000_RP ; ff(399) = 6.271873E-003_RP
    ll(400) = 6.136200E+000_RP ; ff(400) = 6.293880E-003_RP
    ll(401) = 6.168800E+000_RP ; ff(401) = 6.342224E-003_RP
    ll(402) = 6.201600E+000_RP ; ff(402) = 6.400600E-003_RP
    ll(403) = 6.234500E+000_RP ; ff(403) = 6.419854E-003_RP
    ll(404) = 6.267700E+000_RP ; ff(404) = 6.337984E-003_RP
    ll(405) = 6.301000E+000_RP ; ff(405) = 6.166650E-003_RP
    ll(406) = 6.334500E+000_RP ; ff(406) = 5.968535E-003_RP
    ll(407) = 6.368100E+000_RP ; ff(407) = 5.790506E-003_RP
    ll(408) = 6.402000E+000_RP ; ff(408) = 5.641552E-003_RP
    ll(409) = 6.436000E+000_RP ; ff(409) = 5.519912E-003_RP
    ll(410) = 6.470200E+000_RP ; ff(410) = 5.417133E-003_RP
    ll(411) = 6.504600E+000_RP ; ff(411) = 5.328335E-003_RP
    ll(412) = 6.539200E+000_RP ; ff(412) = 5.249985E-003_RP
    ll(413) = 6.573900E+000_RP ; ff(413) = 5.180467E-003_RP
    ll(414) = 6.608900E+000_RP ; ff(414) = 5.117923E-003_RP
    ll(415) = 6.644000E+000_RP ; ff(415) = 5.059937E-003_RP
    ll(416) = 6.679300E+000_RP ; ff(416) = 5.002039E-003_RP
    ll(417) = 6.714800E+000_RP ; ff(417) = 4.944235E-003_RP
    ll(418) = 6.750500E+000_RP ; ff(418) = 4.892367E-003_RP
    ll(419) = 6.786400E+000_RP ; ff(419) = 4.847980E-003_RP
    ll(420) = 6.822400E+000_RP ; ff(420) = 4.803544E-003_RP
    ll(421) = 6.858700E+000_RP ; ff(421) = 4.760787E-003_RP
    ll(422) = 6.895100E+000_RP ; ff(422) = 4.724548E-003_RP
    ll(423) = 6.931800E+000_RP ; ff(423) = 4.686838E-003_RP
    ll(424) = 6.968600E+000_RP ; ff(424) = 4.646554E-003_RP
    ll(425) = 7.005700E+000_RP ; ff(425) = 4.599500E-003_RP
    ll(426) = 7.042900E+000_RP ; ff(426) = 4.544214E-003_RP
    ll(427) = 7.080300E+000_RP ; ff(427) = 4.485537E-003_RP
    ll(428) = 7.118000E+000_RP ; ff(428) = 4.425505E-003_RP
    ll(429) = 7.155800E+000_RP ; ff(429) = 4.371156E-003_RP
    ll(430) = 7.193800E+000_RP ; ff(430) = 4.328369E-003_RP
    ll(431) = 7.232000E+000_RP ; ff(431) = 4.298167E-003_RP
    ll(432) = 7.270500E+000_RP ; ff(432) = 4.278721E-003_RP
    ll(433) = 7.309100E+000_RP ; ff(433) = 4.265937E-003_RP
    ll(434) = 7.348000E+000_RP ; ff(434) = 4.261969E-003_RP
    ll(435) = 7.387000E+000_RP ; ff(435) = 4.267614E-003_RP
    ll(436) = 7.426300E+000_RP ; ff(436) = 4.286198E-003_RP
    ll(437) = 7.465700E+000_RP ; ff(437) = 4.317716E-003_RP
    ll(438) = 7.505400E+000_RP ; ff(438) = 4.363595E-003_RP
    ll(439) = 7.545300E+000_RP ; ff(439) = 4.424256E-003_RP
    ll(440) = 7.585400E+000_RP ; ff(440) = 4.498791E-003_RP
    ll(441) = 7.625700E+000_RP ; ff(441) = 4.576156E-003_RP
    ll(442) = 7.666300E+000_RP ; ff(442) = 4.633967E-003_RP
    ll(443) = 7.707000E+000_RP ; ff(443) = 4.647554E-003_RP
    ll(444) = 7.748000E+000_RP ; ff(444) = 4.614493E-003_RP
    ll(445) = 7.789100E+000_RP ; ff(445) = 4.660863E-003_RP
    ll(446) = 7.830500E+000_RP ; ff(446) = 4.695238E-003_RP
    ll(447) = 7.872200E+000_RP ; ff(447) = 4.701338E-003_RP
    ll(448) = 7.914000E+000_RP ; ff(448) = 4.686730E-003_RP
    ll(449) = 7.956100E+000_RP ; ff(449) = 4.670382E-003_RP
    ll(450) = 7.998300E+000_RP ; ff(450) = 4.670180E-003_RP
    ll(451) = 8.040900E+000_RP ; ff(451) = 4.692610E-003_RP
    ll(452) = 8.083600E+000_RP ; ff(452) = 4.738633E-003_RP
    ll(453) = 8.126500E+000_RP ; ff(453) = 4.804152E-003_RP
    ll(454) = 8.169700E+000_RP ; ff(454) = 4.886835E-003_RP
    ll(455) = 8.213200E+000_RP ; ff(455) = 4.984138E-003_RP
    ll(456) = 8.256800E+000_RP ; ff(456) = 5.094063E-003_RP
    ll(457) = 8.300700E+000_RP ; ff(457) = 5.514989E-003_RP
    ll(458) = 8.344800E+000_RP ; ff(458) = 6.017449E-003_RP
    ll(459) = 8.389200E+000_RP ; ff(459) = 6.538241E-003_RP
    ll(460) = 8.433700E+000_RP ; ff(460) = 7.076836E-003_RP
    ll(461) = 8.478600E+000_RP ; ff(461) = 7.637394E-003_RP
    ll(462) = 8.523600E+000_RP ; ff(462) = 8.207980E-003_RP
    ll(463) = 8.568900E+000_RP ; ff(463) = 8.767093E-003_RP
    ll(464) = 8.614500E+000_RP ; ff(464) = 9.280717E-003_RP
    ll(465) = 8.660300E+000_RP ; ff(465) = 9.748629E-003_RP
    ll(466) = 8.706300E+000_RP ; ff(466) = 1.020015E-002_RP
    ll(467) = 8.752600E+000_RP ; ff(467) = 1.066483E-002_RP
    ll(468) = 8.799100E+000_RP ; ff(468) = 1.115073E-002_RP
    ll(469) = 8.845800E+000_RP ; ff(469) = 1.165717E-002_RP
    ll(470) = 8.892800E+000_RP ; ff(470) = 1.243556E-002_RP
    ll(471) = 8.940100E+000_RP ; ff(471) = 1.326979E-002_RP
    ll(472) = 8.987600E+000_RP ; ff(472) = 1.409857E-002_RP
    ll(473) = 9.035400E+000_RP ; ff(473) = 1.492129E-002_RP
    ll(474) = 9.083400E+000_RP ; ff(474) = 1.573454E-002_RP
    ll(475) = 9.131700E+000_RP ; ff(475) = 1.653834E-002_RP
    ll(476) = 9.180200E+000_RP ; ff(476) = 1.733009E-002_RP
    ll(477) = 9.229000E+000_RP ; ff(477) = 1.811002E-002_RP
    ll(478) = 9.278100E+000_RP ; ff(478) = 1.887696E-002_RP
    ll(479) = 9.327400E+000_RP ; ff(479) = 1.962850E-002_RP
    ll(480) = 9.376900E+000_RP ; ff(480) = 2.036350E-002_RP
    ll(481) = 9.426800E+000_RP ; ff(481) = 2.108429E-002_RP
    ll(482) = 9.476900E+000_RP ; ff(482) = 2.178657E-002_RP
    ll(483) = 9.527200E+000_RP ; ff(483) = 2.243960E-002_RP
    ll(484) = 9.577900E+000_RP ; ff(484) = 2.263137E-002_RP
    ll(485) = 9.628800E+000_RP ; ff(485) = 2.279125E-002_RP
    ll(486) = 9.680000E+000_RP ; ff(486) = 2.292651E-002_RP
    ll(487) = 9.731400E+000_RP ; ff(487) = 2.303866E-002_RP
    ll(488) = 9.783100E+000_RP ; ff(488) = 2.312918E-002_RP
    ll(489) = 9.835100E+000_RP ; ff(489) = 2.319962E-002_RP
    ll(490) = 9.887400E+000_RP ; ff(490) = 2.325072E-002_RP
    ll(491) = 9.939900E+000_RP ; ff(491) = 2.299506E-002_RP
    ll(492) = 9.992800E+000_RP ; ff(492) = 2.253269E-002_RP
    ll(493) = 1.004600E+001_RP ; ff(493) = 2.207975E-002_RP
    ll(494) = 1.009900E+001_RP ; ff(494) = 2.163998E-002_RP
    ll(495) = 1.015300E+001_RP ; ff(495) = 2.120288E-002_RP
    ll(496) = 1.020700E+001_RP ; ff(496) = 2.077663E-002_RP
    ll(497) = 1.026100E+001_RP ; ff(497) = 2.036088E-002_RP
    ll(498) = 1.031600E+001_RP ; ff(498) = 1.995020E-002_RP
    ll(499) = 1.037100E+001_RP ; ff(499) = 1.945672E-002_RP
    ll(500) = 1.042600E+001_RP ; ff(500) = 1.893359E-002_RP
    ll(501) = 1.048100E+001_RP ; ff(501) = 1.842565E-002_RP
    ll(502) = 1.053700E+001_RP ; ff(502) = 1.792392E-002_RP
    ll(503) = 1.059300E+001_RP ; ff(503) = 1.743584E-002_RP
    ll(504) = 1.064900E+001_RP ; ff(504) = 1.685706E-002_RP
    ll(505) = 1.070600E+001_RP ; ff(505) = 1.627722E-002_RP
    ll(506) = 1.076300E+001_RP ; ff(506) = 1.571472E-002_RP
    ll(507) = 1.082000E+001_RP ; ff(507) = 1.516963E-002_RP
    ll(508) = 1.087700E+001_RP ; ff(508) = 1.464261E-002_RP
    ll(509) = 1.093500E+001_RP ; ff(509) = 1.412622E-002_RP
    ll(510) = 1.099300E+001_RP ; ff(510) = 1.363226E-002_RP
    ll(511) = 1.105200E+001_RP ; ff(511) = 1.315689E-002_RP
    ll(512) = 1.111000E+001_RP ; ff(512) = 1.272324E-002_RP
    ll(513) = 1.116900E+001_RP ; ff(513) = 1.231731E-002_RP
    ll(514) = 1.122900E+001_RP ; ff(514) = 1.190468E-002_RP
    ll(515) = 1.128800E+001_RP ; ff(515) = 1.149738E-002_RP
    ll(516) = 1.134800E+001_RP ; ff(516) = 1.105947E-002_RP
    ll(517) = 1.140900E+001_RP ; ff(517) = 1.061030E-002_RP
    ll(518) = 1.146900E+001_RP ; ff(518) = 1.016793E-002_RP
    ll(519) = 1.153000E+001_RP ; ff(519) = 9.722378E-003_RP
    ll(520) = 1.159200E+001_RP ; ff(520) = 9.278651E-003_RP
    ll(521) = 1.165300E+001_RP ; ff(521) = 8.852791E-003_RP
    ll(522) = 1.171500E+001_RP ; ff(522) = 8.429684E-003_RP
    ll(523) = 1.177700E+001_RP ; ff(523) = 8.014923E-003_RP
    ll(524) = 1.184000E+001_RP ; ff(524) = 7.600633E-003_RP
    ll(525) = 1.190300E+001_RP ; ff(525) = 7.192387E-003_RP
    ll(526) = 1.196600E+001_RP ; ff(526) = 6.789709E-003_RP
    ll(527) = 1.203000E+001_RP ; ff(527) = 6.385735E-003_RP
    ll(528) = 1.209400E+001_RP ; ff(528) = 5.986929E-003_RP
    ll(529) = 1.215800E+001_RP ; ff(529) = 5.593216E-003_RP
    ll(530) = 1.222300E+001_RP ; ff(530) = 5.198643E-003_RP
    ll(531) = 1.228800E+001_RP ; ff(531) = 4.809519E-003_RP
    ll(532) = 1.235300E+001_RP ; ff(532) = 4.425472E-003_RP
    ll(533) = 1.241900E+001_RP ; ff(533) = 4.212942E-003_RP
    ll(534) = 1.248500E+001_RP ; ff(534) = 4.196009E-003_RP
    ll(535) = 1.255100E+001_RP ; ff(535) = 4.176633E-003_RP
    ll(536) = 1.261800E+001_RP ; ff(536) = 4.150752E-003_RP
    ll(537) = 1.268500E+001_RP ; ff(537) = 4.116321E-003_RP
    ll(538) = 1.275200E+001_RP ; ff(538) = 4.072901E-003_RP
    ll(539) = 1.282000E+001_RP ; ff(539) = 4.022933E-003_RP
    ll(540) = 1.288800E+001_RP ; ff(540) = 3.970547E-003_RP
    ll(541) = 1.295600E+001_RP ; ff(541) = 3.918878E-003_RP
    ll(542) = 1.302500E+001_RP ; ff(542) = 3.868895E-003_RP
    ll(543) = 1.309500E+001_RP ; ff(543) = 3.821409E-003_RP
    ll(544) = 1.316400E+001_RP ; ff(544) = 3.777640E-003_RP
    ll(545) = 1.323400E+001_RP ; ff(545) = 3.736149E-003_RP
    ll(546) = 1.330400E+001_RP ; ff(546) = 3.696982E-003_RP
    ll(547) = 1.337500E+001_RP ; ff(547) = 3.659270E-003_RP
    ll(548) = 1.344600E+001_RP ; ff(548) = 3.623231E-003_RP
    ll(549) = 1.351800E+001_RP ; ff(549) = 3.588001E-003_RP
    ll(550) = 1.359000E+001_RP ; ff(550) = 3.553883E-003_RP
    ll(551) = 1.366200E+001_RP ; ff(551) = 3.520600E-003_RP
    ll(552) = 1.373400E+001_RP ; ff(552) = 3.488034E-003_RP
    ll(553) = 1.380700E+001_RP ; ff(553) = 3.520342E-003_RP
    ll(554) = 1.388100E+001_RP ; ff(554) = 3.611340E-003_RP
    ll(555) = 1.395500E+001_RP ; ff(555) = 3.703583E-003_RP
    ll(556) = 1.402900E+001_RP ; ff(556) = 3.797520E-003_RP
    ll(557) = 1.410300E+001_RP ; ff(557) = 3.893190E-003_RP
    ll(558) = 1.417800E+001_RP ; ff(558) = 3.991143E-003_RP
    ll(559) = 1.425400E+001_RP ; ff(559) = 4.091370E-003_RP
    ll(560) = 1.432900E+001_RP ; ff(560) = 4.191256E-003_RP
    ll(561) = 1.440500E+001_RP ; ff(561) = 4.293499E-003_RP
    ll(562) = 1.448200E+001_RP ; ff(562) = 4.398077E-003_RP
    ll(563) = 1.455900E+001_RP ; ff(563) = 4.503678E-003_RP
    ll(564) = 1.463600E+001_RP ; ff(564) = 4.610330E-003_RP
    ll(565) = 1.471400E+001_RP ; ff(565) = 4.719344E-003_RP
    ll(566) = 1.479200E+001_RP ; ff(566) = 4.829457E-003_RP
    ll(567) = 1.487100E+001_RP ; ff(567) = 4.942007E-003_RP
    ll(568) = 1.495000E+001_RP ; ff(568) = 5.055625E-003_RP
    ll(569) = 1.502900E+001_RP ; ff(569) = 5.170300E-003_RP
    ll(570) = 1.510900E+001_RP ; ff(570) = 5.287461E-003_RP
    ll(571) = 1.519000E+001_RP ; ff(571) = 5.407177E-003_RP
    ll(572) = 1.527000E+001_RP ; ff(572) = 5.526480E-003_RP
    ll(573) = 1.535200E+001_RP ; ff(573) = 5.649810E-003_RP
    ll(574) = 1.543300E+001_RP ; ff(574) = 5.772747E-003_RP
    ll(575) = 1.551500E+001_RP ; ff(575) = 5.956880E-003_RP
    ll(576) = 1.559800E+001_RP ; ff(576) = 6.233504E-003_RP
    ll(577) = 1.568100E+001_RP ; ff(577) = 6.506662E-003_RP
    ll(578) = 1.576400E+001_RP ; ff(578) = 6.776359E-003_RP
    ll(579) = 1.584800E+001_RP ; ff(579) = 7.045848E-003_RP
    ll(580) = 1.593200E+001_RP ; ff(580) = 7.311870E-003_RP
    ll(581) = 1.601700E+001_RP ; ff(581) = 7.577483E-003_RP
    ll(582) = 1.610200E+001_RP ; ff(582) = 7.840084E-003_RP
    ll(583) = 1.618700E+001_RP ; ff(583) = 8.099342E-003_RP
    ll(584) = 1.627300E+001_RP ; ff(584) = 8.358032E-003_RP
    ll(585) = 1.636000E+001_RP ; ff(585) = 8.616021E-003_RP
    ll(586) = 1.644700E+001_RP ; ff(586) = 8.870279E-003_RP
    ll(587) = 1.653400E+001_RP ; ff(587) = 9.120798E-003_RP
    ll(588) = 1.662200E+001_RP ; ff(588) = 9.370387E-003_RP
    ll(589) = 1.671000E+001_RP ; ff(589) = 9.616036E-003_RP
    ll(590) = 1.679900E+001_RP ; ff(590) = 9.860503E-003_RP
    ll(591) = 1.688800E+001_RP ; ff(591) = 1.010093E-002_RP
    ll(592) = 1.697800E+001_RP ; ff(592) = 1.033984E-002_RP
    ll(593) = 1.706800E+001_RP ; ff(593) = 1.057452E-002_RP
    ll(594) = 1.715900E+001_RP ; ff(594) = 1.080731E-002_RP
    ll(595) = 1.725000E+001_RP ; ff(595) = 1.103572E-002_RP
    ll(596) = 1.734200E+001_RP ; ff(596) = 1.126186E-002_RP
    ll(597) = 1.743400E+001_RP ; ff(597) = 1.148327E-002_RP
    ll(598) = 1.752700E+001_RP ; ff(598) = 1.170201E-002_RP
    ll(599) = 1.762000E+001_RP ; ff(599) = 1.191568E-002_RP
    ll(600) = 1.771400E+001_RP ; ff(600) = 1.201592E-002_RP
    ll(601) = 1.780800E+001_RP ; ff(601) = 1.193910E-002_RP
    ll(602) = 1.790200E+001_RP ; ff(602) = 1.186173E-002_RP
    ll(603) = 1.799800E+001_RP ; ff(603) = 1.178241E-002_RP
    ll(604) = 1.809300E+001_RP ; ff(604) = 1.170357E-002_RP
    ll(605) = 1.818900E+001_RP ; ff(605) = 1.162358E-002_RP
    ll(606) = 1.828600E+001_RP ; ff(606) = 1.154249E-002_RP
    ll(607) = 1.838300E+001_RP ; ff(607) = 1.146122E-002_RP
    ll(608) = 1.848100E+001_RP ; ff(608) = 1.137915E-002_RP
    ll(609) = 1.857900E+001_RP ; ff(609) = 1.129707E-002_RP
    ll(610) = 1.867800E+001_RP ; ff(610) = 1.121409E-002_RP
    ll(611) = 1.877700E+001_RP ; ff(611) = 1.113103E-002_RP
    ll(612) = 1.887700E+001_RP ; ff(612) = 1.104721E-002_RP
    ll(613) = 1.897700E+001_RP ; ff(613) = 1.096348E-002_RP
    ll(614) = 1.907800E+001_RP ; ff(614) = 1.087901E-002_RP
    ll(615) = 1.918000E+001_RP ; ff(615) = 1.079390E-002_RP
    ll(616) = 1.928100E+001_RP ; ff(616) = 1.070973E-002_RP
    ll(617) = 1.938400E+001_RP ; ff(617) = 1.062421E-002_RP
    ll(618) = 1.948700E+001_RP ; ff(618) = 1.053895E-002_RP
    ll(619) = 1.959100E+001_RP ; ff(619) = 1.045308E-002_RP
    ll(620) = 1.969500E+001_RP ; ff(620) = 1.036764E-002_RP
    ll(621) = 1.979900E+001_RP ; ff(621) = 1.028252E-002_RP
    ll(622) = 1.990500E+001_RP ; ff(622) = 1.019615E-002_RP
    ll(623) = 2.001000E+001_RP ; ff(623) = 1.011106E-002_RP
    ll(624) = 2.011700E+001_RP ; ff(624) = 1.002481E-002_RP
    ll(625) = 2.022400E+001_RP ; ff(625) = 9.939051E-003_RP
    ll(626) = 2.033100E+001_RP ; ff(626) = 9.853849E-003_RP
    ll(627) = 2.043900E+001_RP ; ff(627) = 9.768301E-003_RP
    ll(628) = 2.054800E+001_RP ; ff(628) = 9.682507E-003_RP
    ll(629) = 2.065700E+001_RP ; ff(629) = 9.602100E-003_RP
    ll(630) = 2.076700E+001_RP ; ff(630) = 9.507339E-003_RP
    ll(631) = 2.087700E+001_RP ; ff(631) = 9.412261E-003_RP
    ll(632) = 2.098800E+001_RP ; ff(632) = 9.317517E-003_RP
    ll(633) = 2.110000E+001_RP ; ff(633) = 9.223271E-003_RP
    ll(634) = 2.121200E+001_RP ; ff(634) = 9.130442E-003_RP
    ll(635) = 2.132400E+001_RP ; ff(635) = 9.038717E-003_RP
    ll(636) = 2.143800E+001_RP ; ff(636) = 8.946685E-003_RP
    ll(637) = 2.155200E+001_RP ; ff(637) = 8.855852E-003_RP
    ll(638) = 2.166600E+001_RP ; ff(638) = 8.766194E-003_RP
    ll(639) = 2.178100E+001_RP ; ff(639) = 8.676901E-003_RP
    ll(640) = 2.189700E+001_RP ; ff(640) = 8.588113E-003_RP
    ll(641) = 2.201400E+001_RP ; ff(641) = 8.499749E-003_RP
    ll(642) = 2.213100E+001_RP ; ff(642) = 8.412538E-003_RP
    ll(643) = 2.224800E+001_RP ; ff(643) = 8.326530E-003_RP
    ll(644) = 2.236600E+001_RP ; ff(644) = 8.240941E-003_RP
    ll(645) = 2.248500E+001_RP ; ff(645) = 8.155746E-003_RP
    ll(646) = 2.260500E+001_RP ; ff(646) = 8.071026E-003_RP
    ll(647) = 2.272500E+001_RP ; ff(647) = 7.987429E-003_RP
    ll(648) = 2.284600E+001_RP ; ff(648) = 7.904291E-003_RP
    ll(649) = 2.296700E+001_RP ; ff(649) = 7.822277E-003_RP
    ll(650) = 2.308900E+001_RP ; ff(650) = 7.740706E-003_RP
    ll(651) = 2.321200E+001_RP ; ff(651) = 7.659593E-003_RP
    ll(652) = 2.333500E+001_RP ; ff(652) = 7.579566E-003_RP
    ll(653) = 2.345900E+001_RP ; ff(653) = 7.500028E-003_RP
    ll(654) = 2.358400E+001_RP ; ff(654) = 7.420889E-003_RP
    ll(655) = 2.370900E+001_RP ; ff(655) = 7.342861E-003_RP
    ll(656) = 2.383500E+001_RP ; ff(656) = 7.265323E-003_RP
    ll(657) = 2.396200E+001_RP ; ff(657) = 7.188227E-003_RP
    ll(658) = 2.408900E+001_RP ; ff(658) = 7.112164E-003_RP
    ll(659) = 2.421700E+001_RP ; ff(659) = 7.036685E-003_RP
    ll(660) = 2.434600E+001_RP ; ff(660) = 6.961662E-003_RP
    ll(661) = 2.447600E+001_RP ; ff(661) = 6.887165E-003_RP
    ll(662) = 2.460600E+001_RP ; ff(662) = 6.813678E-003_RP
    ll(663) = 2.473600E+001_RP ; ff(663) = 6.741208E-003_RP
    ll(664) = 2.486800E+001_RP ; ff(664) = 6.671417E-003_RP
    ll(665) = 2.500000E+001_RP ; ff(665) = 6.603864E-003_RP
    ll(666) = 2.659600E+001_RP ; ff(666) = 5.854731E-003_RP
    ll(667) = 2.829500E+001_RP ; ff(667) = 5.176442E-003_RP
    ll(668) = 3.010100E+001_RP ; ff(668) = 4.565132E-003_RP
    ll(669) = 3.202300E+001_RP ; ff(669) = 4.055596E-003_RP
    ll(670) = 3.406800E+001_RP ; ff(670) = 3.624763E-003_RP
    ll(671) = 3.624300E+001_RP ; ff(671) = 3.230220E-003_RP
    ll(672) = 3.855700E+001_RP ; ff(672) = 2.870153E-003_RP
    ll(673) = 4.101900E+001_RP ; ff(673) = 2.541639E-003_RP
    ll(674) = 4.363800E+001_RP ; ff(674) = 2.252124E-003_RP
    ll(675) = 4.642500E+001_RP ; ff(675) = 1.988811E-003_RP
    ll(676) = 4.938900E+001_RP ; ff(676) = 1.748948E-003_RP
    ll(677) = 5.254300E+001_RP ; ff(677) = 1.530858E-003_RP
    ll(678) = 5.589800E+001_RP ; ff(678) = 1.333111E-003_RP
    ll(679) = 5.946700E+001_RP ; ff(679) = 1.154482E-003_RP
    ll(680) = 6.326400E+001_RP ; ff(680) = 1.009940E-003_RP
    ll(681) = 6.730300E+001_RP ; ff(681) = 8.987509E-004_RP
    ll(682) = 7.160100E+001_RP ; ff(682) = 7.942530E-004_RP
    ll(683) = 7.617300E+001_RP ; ff(683) = 7.009912E-004_RP
    ll(684) = 8.103600E+001_RP ; ff(684) = 6.194887E-004_RP
    ll(685) = 8.621100E+001_RP ; ff(685) = 5.515434E-004_RP
    ll(686) = 9.171500E+001_RP ; ff(686) = 4.887247E-004_RP
    ll(687) = 9.757200E+001_RP ; ff(687) = 4.328822E-004_RP
    ll(688) = 1.038000E+002_RP ; ff(688) = 3.860034E-004_RP
    ll(689) = 1.104300E+002_RP ; ff(689) = 3.469194E-004_RP
    ll(690) = 1.174800E+002_RP ; ff(690) = 3.104210E-004_RP
    ll(691) = 1.249800E+002_RP ; ff(691) = 2.761359E-004_RP
    ll(692) = 1.329600E+002_RP ; ff(692) = 2.441382E-004_RP
    ll(693) = 1.414500E+002_RP ; ff(693) = 2.145920E-004_RP
    ll(694) = 1.504800E+002_RP ; ff(694) = 1.885659E-004_RP
    ll(695) = 1.600900E+002_RP ; ff(695) = 1.699541E-004_RP
    ll(696) = 1.703100E+002_RP ; ff(696) = 1.518407E-004_RP
    ll(697) = 1.811900E+002_RP ; ff(697) = 1.365328E-004_RP
    ll(698) = 1.927600E+002_RP ; ff(698) = 1.211470E-004_RP
    ll(699) = 2.050700E+002_RP ; ff(699) = 1.084742E-004_RP
    ll(700) = 2.181600E+002_RP ; ff(700) = 9.908348E-005_RP
    ll(701) = 2.320900E+002_RP ; ff(701) = 8.954472E-005_RP
    ll(702) = 2.469100E+002_RP ; ff(702) = 8.046143E-005_RP
    ll(703) = 2.626800E+002_RP ; ff(703) = 7.134690E-005_RP
    ll(704) = 2.794500E+002_RP ; ff(704) = 6.417476E-005_RP
    ll(705) = 2.972900E+002_RP ; ff(705) = 5.640202E-005_RP
    ll(706) = 3.162700E+002_RP ; ff(706) = 5.043546E-005_RP
    ll(707) = 3.364700E+002_RP ; ff(707) = 4.545317E-005_RP
    ll(708) = 3.579500E+002_RP ; ff(708) = 4.077735E-005_RP
    ll(709) = 3.808100E+002_RP ; ff(709) = 3.675313E-005_RP
    ll(710) = 4.051200E+002_RP ; ff(710) = 3.317996E-005_RP
    ll(711) = 4.309900E+002_RP ; ff(711) = 2.985413E-005_RP
    ll(712) = 4.585100E+002_RP ; ff(712) = 2.693351E-005_RP
    ll(713) = 4.877900E+002_RP ; ff(713) = 2.435487E-005_RP
    ll(714) = 5.189300E+002_RP ; ff(714) = 2.196950E-005_RP
    ll(715) = 5.520700E+002_RP ; ff(715) = 1.986945E-005_RP
    ll(716) = 5.873200E+002_RP ; ff(716) = 1.798194E-005_RP
    ll(717) = 6.248200E+002_RP ; ff(717) = 1.628420E-005_RP
    ll(718) = 6.647100E+002_RP ; ff(718) = 1.475651E-005_RP
    ll(719) = 7.071600E+002_RP ; ff(719) = 1.338033E-005_RP
    ll(720) = 7.523100E+002_RP ; ff(720) = 1.214071E-005_RP
    ll(721) = 8.003500E+002_RP ; ff(721) = 1.102292E-005_RP
    ll(722) = 8.514500E+002_RP ; ff(722) = 1.001474E-005_RP
    ll(723) = 9.058200E+002_RP ; ff(723) = 9.104517E-006_RP
    ll(724) = 9.636600E+002_RP ; ff(724) = 8.282437E-006_RP
    ll(725) = 1.025200E+003_RP ; ff(725) = 7.539334E-006_RP
    ll(726) = 1.090600E+003_RP ; ff(726) = 6.867948E-006_RP
    ll(727) = 1.160300E+003_RP ; ff(727) = 6.259329E-006_RP
    ll(728) = 1.234400E+003_RP ; ff(728) = 5.708603E-006_RP
    ll(729) = 1.313200E+003_RP ; ff(729) = 5.209774E-006_RP
    ll(730) = 1.397000E+003_RP ; ff(730) = 4.757622E-006_RP
    ll(731) = 1.486200E+003_RP ; ff(731) = 4.347118E-006_RP
    ll(732) = 1.581100E+003_RP ; ff(732) = 3.974453E-006_RP
    ll(733) = 1.682100E+003_RP ; ff(733) = 3.635790E-006_RP
    ll(734) = 1.789500E+003_RP ; ff(734) = 3.328032E-006_RP
    ll(735) = 1.903800E+003_RP ; ff(735) = 3.047996E-006_RP
    ll(736) = 2.025300E+003_RP ; ff(736) = 2.793291E-006_RP
    ll(737) = 2.154600E+003_RP ; ff(737) = 2.561234E-006_RP
    ll(738) = 2.292200E+003_RP ; ff(738) = 2.349667E-006_RP
    ll(739) = 2.438600E+003_RP ; ff(739) = 2.156696E-006_RP
    ll(740) = 2.594300E+003_RP ; ff(740) = 1.980678E-006_RP
    ll(741) = 2.759900E+003_RP ; ff(741) = 1.819989E-006_RP
    ll(742) = 2.936200E+003_RP ; ff(742) = 1.673071E-006_RP
    ll(743) = 3.123600E+003_RP ; ff(743) = 1.538877E-006_RP
    ll(744) = 3.323100E+003_RP ; ff(744) = 1.416027E-006_RP
    ll(745) = 3.535300E+003_RP ; ff(745) = 1.303610E-006_RP
    ll(746) = 3.761000E+003_RP ; ff(746) = 1.200683E-006_RP
    ll(747) = 4.001200E+003_RP ; ff(747) = 1.106331E-006_RP
    ll(748) = 4.256600E+003_RP ; ff(748) = 1.019874E-006_RP
    ll(749) = 4.528400E+003_RP ; ff(749) = 9.405306E-007_RP
    ll(750) = 4.817600E+003_RP ; ff(750) = 8.676979E-007_RP
    ll(751) = 5.125200E+003_RP ; ff(751) = 8.008284E-007_RP
    ll(752) = 5.452400E+003_RP ; ff(752) = 7.394052E-007_RP
    ll(753) = 5.800600E+003_RP ; ff(753) = 6.829179E-007_RP
    ll(754) = 6.171000E+003_RP ; ff(754) = 6.309748E-007_RP
    ll(755) = 6.565000E+003_RP ; ff(755) = 5.831868E-007_RP
    ll(756) = 6.984200E+003_RP ; ff(756) = 5.391948E-007_RP
    ll(757) = 7.430100E+003_RP ; ff(757) = 4.986850E-007_RP
    ll(758) = 7.904600E+003_RP ; ff(758) = 4.613430E-007_RP
    ll(759) = 8.409300E+003_RP ; ff(759) = 4.269397E-007_RP
    ll(760) = 8.946200E+003_RP ; ff(760) = 3.952130E-007_RP
    ll(761) = 9.517400E+003_RP ; ff(761) = 3.659366E-007_RP
    ll(762) = 1.012500E+004_RP ; ff(762) = 3.389289E-007_RP
    ll(763) = 1.077200E+004_RP ; ff(763) = 3.139718E-007_RP
    ll(764) = 1.145900E+004_RP ; ff(764) = 2.909651E-007_RP
    ll(765) = 1.219100E+004_RP ; ff(765) = 2.696762E-007_RP
    ll(766) = 1.297000E+004_RP ; ff(766) = 2.499955E-007_RP
    ll(767) = 1.379800E+004_RP ; ff(767) = 2.318190E-007_RP
    ll(768) = 1.467900E+004_RP ; ff(768) = 2.150057E-007_RP
    ll(769) = 1.561600E+004_RP ; ff(769) = 1.994566E-007_RP
    ll(770) = 1.661300E+004_RP ; ff(770) = 1.850660E-007_RP
    ll(771) = 1.767400E+004_RP ; ff(771) = 1.717421E-007_RP
    ll(772) = 1.880200E+004_RP ; ff(772) = 1.594122E-007_RP
    ll(773) = 2.000300E+004_RP ; ff(773) = 1.479849E-007_RP
    ll(774) = 2.128000E+004_RP ; ff(774) = 1.374047E-007_RP
    ll(775) = 2.263900E+004_RP ; ff(775) = 1.275984E-007_RP
    ll(776) = 2.408400E+004_RP ; ff(776) = 1.185140E-007_RP
    ll(777) = 2.562200E+004_RP ; ff(777) = 1.100899E-007_RP
    ll(778) = 2.725800E+004_RP ; ff(778) = 1.022785E-007_RP
    ll(779) = 2.899900E+004_RP ; ff(779) = 9.503267E-008_RP
    ll(780) = 3.085000E+004_RP ; ff(780) = 8.831560E-008_RP
    ll(781) = 3.282000E+004_RP ; ff(781) = 8.208115E-008_RP
    ll(782) = 3.491600E+004_RP ; ff(782) = 7.629548E-008_RP
    ll(783) = 3.714500E+004_RP ; ff(783) = 7.092756E-008_RP
    ll(784) = 3.951700E+004_RP ; ff(784) = 6.594324E-008_RP
    ll(785) = 4.204000E+004_RP ; ff(785) = 6.131608E-008_RP
    ll(786) = 4.472500E+004_RP ; ff(786) = 5.701886E-008_RP
    ll(787) = 4.758000E+004_RP ; ff(787) = 5.302912E-008_RP
    ll(788) = 5.061800E+004_RP ; ff(788) = 4.932266E-008_RP
    ll(789) = 5.385000E+004_RP ; ff(789) = 4.587939E-008_RP
    ll(790) = 5.728900E+004_RP ; ff(790) = 4.267944E-008_RP
    ll(791) = 6.094700E+004_RP ; ff(791) = 3.970676E-008_RP
    ll(792) = 6.483800E+004_RP ; ff(792) = 3.694393E-008_RP
    ll(793) = 6.897800E+004_RP ; ff(793) = 3.437614E-008_RP
    ll(794) = 7.338300E+004_RP ; ff(794) = 3.198857E-008_RP
    ll(795) = 7.806800E+004_RP ; ff(795) = 2.976956E-008_RP
    ll(796) = 8.305300E+004_RP ; ff(796) = 2.770585E-008_RP
    ll(797) = 8.835600E+004_RP ; ff(797) = 2.578741E-008_RP
    ll(798) = 9.399800E+004_RP ; ff(798) = 2.400303E-008_RP
    ll(799) = 1.000000E+005_RP ; ff(799) = 2.234349E-008_RP
! Table !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

! Convert to Angstroms !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!    
    ll(0:799) = ll(0:799) * 1.0E+004_RP

    aux(0) = 5500.0_RP
    call SPLINE1DArr( aux,x,1,ll,ff,800,e,0 )
    call SPLINE1DArr(   l,q,n,ll,ff,800,e,0 )

! Restrict to positive values -----------------------------------------------
    where ( q(0:n-1) > 0.0_RP )
       q(0:n-1) = q(0:n-1) / x(0)
    elsewhere
       q(0:n-1) = 0.0_RP
    end where
    
END SUBROUTINE J13__LawOPT
! ###########################################################################

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
SUBROUTINE J13__LawOPT_info( a )
  use ModDataType

  implicit none
  
  character (len=58), intent(out) :: a
  
  !f2py intent(out) :: a
  
  a = 'Jones et al. (2013) + Koehler et al. (2014) extinction law'
  
END SUBROUTINE J13__LawOPT_info
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
SUBROUTINE J13__LawOPT_author( a )
  use ModDataType

  implicit none
  
  character (len=21), intent(out) :: a
  
  !f2py intent(out) :: a
  
  a = 'Written by Jean Gomes'
  
END SUBROUTINE J13__LawOPT_author
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!PROGRAM GeneralProgram
!
!
!END PROGRAM GeneralProgram
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
